==> gnome-db-0.2.3.tar.gz: gnome-db-0.2.3/lib/gnome-db-entry.c <==
/* GNOME DB library
 * Copyright (C) 1999-2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gnome-db-entry.h>

struct _GnomeDbEntryPrivate {
	Gda_Recordset* recset;
	gint           col;
};

/*
 * Callbacks
 */
static void
row_changed_cb (Gda_Recordset *rs, GnomeDbEntry *entry) {
	Gda_Field* field;
	
	g_return_if_fail(IS_GDA_RECORDSET(rs));
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	g_return_if_fail(entry->priv->recset == rs);
	
	field = gda_recordset_field_idx(entry->priv->recset, entry->priv->col);
	if (field) {
		gnome_db_entry_set_text(entry, gda_stringify_value(0, 0, field));
	}
}

/*
 * Private functions
 */
static void
_gnome_db_entry_destroy (GnomeDbEntry *entry, gpointer user_data) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	
	if (entry->priv) {
		if (IS_GDA_RECORDSET(entry->priv->recset))
			gtk_object_unref(GTK_OBJECT(entry->priv->recset));
		g_free((gpointer) entry->priv);
	}
}

static void
_gnome_db_entry_class_init (GnomeDbEntryClass *klass) {
}

static void
_gnome_db_entry_init (GnomeDbEntry *entry) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	
	entry->priv = g_new0(GnomeDbEntryPrivate, 1);
	gtk_signal_connect(GTK_OBJECT(entry),
	                   "destroy",
	                   GTK_SIGNAL_FUNC(_gnome_db_entry_destroy),
	                   NULL);
}

/*
 * Public functions
 */
GtkType
gnome_db_entry_get_type (void) {
	static GtkType db_entry_type = 0;
	
	if (!db_entry_type) {
		GtkTypeInfo db_entry_info = {
			"GnomeDbEntry",
			sizeof (GnomeDbEntry),
			sizeof (GnomeDbEntryClass),
			(GtkClassInitFunc) _gnome_db_entry_class_init,
			(GtkObjectInitFunc) _gnome_db_entry_init,
			(GtkArgSetFunc) NULL,
			(GtkArgGetFunc) NULL
		};
		db_entry_type = gtk_type_unique(gtk_entry_get_type(), &db_entry_info);
	}
	return (db_entry_type);
}

/**
 * gnome_db_entry_new
 */
GtkWidget *
gnome_db_entry_new (Gda_Recordset *recset, gint col) {
	GnomeDbEntry* entry;
	
	entry = GNOME_DB_ENTRY(gtk_type_new(gnome_db_entry_get_type()));
	if (IS_GDA_RECORDSET(recset))
		gnome_db_entry_set_recordset(entry, recset, col);
	return GTK_WIDGET(entry);
}

/**
 * gnome_db_entry_get_recordset
 */
Gda_Recordset *
gnome_db_entry_get_recordset (GnomeDbEntry *entry) {
	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
	g_return_val_if_fail(entry->priv != NULL, NULL);
	return entry->priv->recset;
}

/**
 * gnome_db_entry_set_recordset
 */
void
gnome_db_entry_set_recordset (GnomeDbEntry *entry, Gda_Recordset *recset, gint col) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	g_return_if_fail(entry->priv != NULL);
	
	/* remove the currently active recordset */
	if (IS_GDA_RECORDSET(entry->priv->recset)) {
		gtk_signal_disconnect(GTK_OBJECT(entry->priv->recset),
		                      gtk_signal_lookup("row_changed", gda_recordset_get_type()));
		gtk_object_unref(GTK_OBJECT(entry->priv->recset));
	}
	
	/* set the new recordset */
	entry->priv->recset = recset;
	entry->priv->col = col;
	gtk_signal_connect(GTK_OBJECT(entry->priv->recset),
	                   "row_changed",
	                   GTK_SIGNAL_FUNC(row_changed_cb),
	                   (gpointer) entry);
	gtk_object_ref(GTK_OBJECT(entry->priv->recset));
}

/**
 * gnome_db_entry_get_text
 */
const gchar *
gnome_db_entry_get_text (GnomeDbEntry *entry) {
	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
	return (const gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
}

/**
 * gnome_db_entry_set_text
 */
void
gnome_db_entry_set_text (GnomeDbEntry *entry, const gchar *txt) {
}

==> gnome-db-0.2.9.tar.gz: gnome-db-0.2.9/lib/gnome-db-entry.c <==
/* GNOME DB library
 * Copyright (C) 1999-2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gnome-db-entry.h>

struct _GnomeDbEntryPrivate {
	GdaRecordset* recset;
	gint           col;
};

/*
 * Callbacks
 */
static void
row_changed_cb (GdaRecordset *rs, GnomeDbEntry *entry) {
	GdaField* field;
	
	g_return_if_fail(IS_GDA_RECORDSET(rs));
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	g_return_if_fail(entry->priv->recset == rs);
	
	field = gda_recordset_field_idx(entry->priv->recset, entry->priv->col);
	if (field) {
		gnome_db_entry_set_text(entry, gda_stringify_value(0, 0, field));
	}
}

/*
 * Private functions
 */
static void
_gnome_db_entry_destroy (GnomeDbEntry *entry, gpointer user_data) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	
	if (entry->priv) {
		if (IS_GDA_RECORDSET(entry->priv->recset))
			gtk_object_unref(GTK_OBJECT(entry->priv->recset));
		g_free((gpointer) entry->priv);
	}
}

static void
_gnome_db_entry_class_init (GnomeDbEntryClass *klass) {
}

static void
_gnome_db_entry_init (GnomeDbEntry *entry) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	
	entry->priv = g_new0(GnomeDbEntryPrivate, 1);
	gtk_signal_connect(GTK_OBJECT(entry),
	                   "destroy",
	                   GTK_SIGNAL_FUNC(_gnome_db_entry_destroy),
	                   NULL);
}

/*
 * Public functions
 */
GtkType
gnome_db_entry_get_type (void) {
	static GtkType db_entry_type = 0;
	
	if (!db_entry_type) {
		GtkTypeInfo db_entry_info = {
			"GnomeDbEntry",
			sizeof (GnomeDbEntry),
			sizeof (GnomeDbEntryClass),
			(GtkClassInitFunc) _gnome_db_entry_class_init,
			(GtkObjectInitFunc) _gnome_db_entry_init,
			(GtkArgSetFunc) NULL,
			(GtkArgGetFunc) NULL
		};
		db_entry_type = gtk_type_unique(gtk_entry_get_type(), &db_entry_info);
	}
	return (db_entry_type);
}

/**
 * gnome_db_entry_new
 */
GtkWidget *
gnome_db_entry_new (GdaRecordset *recset, gint col) {
	GnomeDbEntry* entry;
	
	entry = GNOME_DB_ENTRY(gtk_type_new(gnome_db_entry_get_type()));
	if (IS_GDA_RECORDSET(recset))
		gnome_db_entry_set_recordset(entry, recset, col);
	return GTK_WIDGET(entry);
}

/**
 * gnome_db_entry_get_recordset
 */
GdaRecordset *
gnome_db_entry_get_recordset (GnomeDbEntry *entry) {
	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
	g_return_val_if_fail(entry->priv != NULL, NULL);
	return entry->priv->recset;
}

/**
 * gnome_db_entry_set_recordset
 */
void
gnome_db_entry_set_recordset (GnomeDbEntry *entry, GdaRecordset *recset, gint col) {
	g_return_if_fail(GNOME_DB_IS_ENTRY(entry));
	g_return_if_fail(entry->priv != NULL);
	
	/* remove the currently active recordset */
	if (IS_GDA_RECORDSET(entry->priv->recset)) {
		gtk_signal_disconnect(GTK_OBJECT(entry->priv->recset),
		                      gtk_signal_lookup("row_changed", gda_recordset_get_type()));
		gtk_object_unref(GTK_OBJECT(entry->priv->recset));
	}
	
	/* set the new recordset */
	entry->priv->recset = recset;
	entry->priv->col = col;
	gtk_signal_connect(GTK_OBJECT(entry->priv->recset),
	                   "row_changed",
	                   GTK_SIGNAL_FUNC(row_changed_cb),
	                   (gpointer) entry);
	gtk_object_ref(GTK_OBJECT(entry->priv->recset));
}

/**
 * gnome_db_entry_get_text
 */
const gchar *
gnome_db_entry_get_text (GnomeDbEntry *entry) {
	g_return_val_if_fail(GNOME_DB_IS_ENTRY(entry), NULL);
	return (const gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
}

/**
 * gnome_db_entry_set_text
 */
void
gnome_db_entry_set_text (GnomeDbEntry *entry, const gchar *txt) {
}
